@@ -3,7 +3,7 @@ package App::DualLivedList;
 use 5.005;
 use strict;
 
-our $VERSION = '0.00_07';
+our $VERSION = '0.00_08';
 
 1;
 __END__
@@ -15,7 +15,7 @@ App-DualLivedList - Perl extension to determine if
 
 =head1 SYNOPSIS
 
-dual-lived < module_name > 
+dual-lived <module_name> 
   
 =head1 DESCRIPTION
 
@@ -44,14 +44,34 @@ dual-lived /word/ - searchs the entire CPAN for "word"
      
 dual-lived /^*/   - returns all of the modules on CPAN.                                        
 
+=head2 OPTIONS
+
+You can use one option at a time, or you may bundle them.
+For example,
+             dual-lived CPAN -f
+             dual-lived CPAN -df
+             dual-lived CPAN -dfu
+             
+To check the module list and author list:
+             dual-lived // -al
+
+-A | --alpha   = alphabetical list of authors by CPAN_ID
+-a | --authors = list of authors by module appearance
+-d | --distributions = gives the distribution name from 
+                 which the dual-lived modules derives
+-f | --filestats = gives file size, line length, and word count
+-l | --list      = DualLivedList of modules
+-u | --upgrade   = installs or upgrades a module
+-v | --version   = App::DualLivedList version number 
+                   
 =head1 CAVEATS
 
 App::DualLivedList covers the latest stable perl
-which is 5.12.2
+which is 5.12.3
 
 =head1 AUTHOR
 
-Version 0.00_07 Kevin W. Henwood <Khen1950fx@aol.com>
+Version 0.00_08 Kevin W. Henwood <Khen1950fx@aol.com>
 
 =head1 COPYRIGHT AND LICENSE
 
